{ GnuPGInterface.pas - GnuPG components/ interface component

 	Copyright (C) 2003 - 20xx Stephan Stapel
        (stephan.stapel@web.de)

  This file is part of gnupgcomponents, ocx package.

  GnuPGEngine and GnuPGPublickeyring is free software;
  you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
}

unit GnuPGInterface;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, GnuPGEngine, GnuPGPublickeyring;

type
  TGnuPGInterface = class(TWinControl)
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  private
    mEngine        : TGnuPGEngine;
    mKeyring       : TGnuPGPublickeyring;
    mGnuPGFilePath : String;
    mKeyList       : TStringList;
  private
    function CompileName(aUserID: TKeyUserID): String;
  public
    function encryptFile(keyId: String; sourceFile: String; targetFile: String): Boolean;
    function signEncryptFile(keyId: String; sourceFile: String; targetFile: String): Boolean;
    function enumPublicKeys : Boolean;
    function getNumPublicKeys : Integer;
    function getPublicKeyId(index : Integer) : String;
    procedure SetGnuPGFilePath(filepath : String);
  end;

procedure Register;

implementation



procedure Register;
begin
  RegisterComponents('Beispiele', [TGnuPGInterface]);
end;







constructor TGnuPGInterface.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);

  mEngine  := TGnuPGEngine.Create(self);
  mKeyring := TGnuPGPublickeyring.Create(self);
  mKeyList := TStringList.Create;

  SetGnuPGFilePath('c:\gnupg\gpg.exe');
end; // !Create()



destructor TGnuPGInterface.Destroy;
begin
   mEngine.Destroy;
   mKeyring.Destroy;
   mKeyList.Destroy;

   inherited Destroy;
end; // !Destroy()


function TGnuPGInterface.encryptFile(keyId: String; sourceFile: String; targetFile: String): Boolean;
begin
  if FileExists(targetFile) then begin
    if FileExists(targetFile + '.bck') then begin
      DeleteFile(targetFile + '.bck');
    end;
    RenameFile(targetFile, targetFile + '.bck');
  end;

  result := mEngine.EncryptFileToFile(keyId, sourceFile, targetFile);
end; // !encryptFile()



function TGnuPGInterface.signEncryptFile(keyId: String; sourceFile: String; targetFile: String): Boolean;
begin
  if FileExists(targetFile) then begin
    if FileExists(targetFile + '_bck') then begin
      DeleteFile(targetFile + '_bck');
    end;
    RenameFile(targetFile, targetFile + '_bck');
  end;

  result := mEngine.SignEncryptFileToFile(keyId, sourceFile, targetFile);
end; // !signEncryptFile()



function TGnuPGInterface.enumPublicKeys : Boolean;
var i, j    : Integer;
    keyItem : TKeyringItem;
    test    : Integer;
begin
  mKeyList.Clear;

  mKeyring.Refresh;
  test := mKeyring.GetKeyCount;
  Caption := IntToStr(test);

  for i := 0 to mKeyring.GetKeyCount - 1 do begin
    keyItem := mKeyring.GetKeyInfoFromIndex(i);
    for j := 0 to keyItem.GetUserIDCount - 1 do begin
      mKeyList.Append(compilename(keyItem.GetUserIDFromIndex(j)));
    end;
  end;

  result := true;
end; // !enumPublicKeys()



function TGnuPGInterface.getNumPublicKeys : Integer;
begin
  result := mKeyList.Count;
end; // !getNumPublicKeys()



function TGnuPGInterface.getPublicKeyId(index : Integer) : String;
begin
  if (index < 0) or (index > mKeyList.Count) then begin
    result := '';
  end
  else begin
    result := mKeyList.Strings[index];
  end;
end; // !getPublicKeyId()



procedure TGnuPGInterface.SetGnuPGFilePath(filepath : String);
begin
  mGnuPGFilePath    := filepath;
  mEngine.Filename  := filepath;
  mKeyring.Filename := filepath;
end; // !SetGnuPGFilePath()



function TGnuPGInterface.CompileName(aUserID: TKeyUserID): String;
var Name: String;
begin
  Name:=aUserID.Name;
  if Length(aUserID.Comment)>0 then
    Name:=Name+' ('+aUserID.Comment+')';
  if Length(aUserID.email)>0 then
    Name:=Name+' <'+aUserID.email+'>';
  result:=Name;
end;


end.
